# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.0.0

import enum

import winrt.system
from winrt._winrt_windows_ui_xaml_automation_peers import (
    RawElementProviderRuntimeId,
    AppBarAutomationPeer,
    AppBarButtonAutomationPeer,
    AppBarToggleButtonAutomationPeer,
    AutoSuggestBoxAutomationPeer,
    AutomationPeer,
    AutomationPeerAnnotation,
    ButtonAutomationPeer,
    ButtonBaseAutomationPeer,
    CalendarDatePickerAutomationPeer,
    CaptureElementAutomationPeer,
    CheckBoxAutomationPeer,
    ColorPickerSliderAutomationPeer,
    ColorSpectrumAutomationPeer,
    ComboBoxAutomationPeer,
    ComboBoxItemAutomationPeer,
    ComboBoxItemDataAutomationPeer,
    DatePickerAutomationPeer,
    DatePickerFlyoutPresenterAutomationPeer,
    FlipViewAutomationPeer,
    FlipViewItemAutomationPeer,
    FlipViewItemDataAutomationPeer,
    FlyoutPresenterAutomationPeer,
    FrameworkElementAutomationPeer,
    GridViewAutomationPeer,
    GridViewHeaderItemAutomationPeer,
    GridViewItemAutomationPeer,
    GridViewItemDataAutomationPeer,
    GroupItemAutomationPeer,
    HubAutomationPeer,
    HubSectionAutomationPeer,
    HyperlinkButtonAutomationPeer,
    ImageAutomationPeer,
    InkToolbarAutomationPeer,
    ItemAutomationPeer,
    ItemsControlAutomationPeer,
    ListBoxAutomationPeer,
    ListBoxItemAutomationPeer,
    ListBoxItemDataAutomationPeer,
    ListPickerFlyoutPresenterAutomationPeer,
    ListViewAutomationPeer,
    ListViewBaseAutomationPeer,
    ListViewBaseHeaderItemAutomationPeer,
    ListViewHeaderItemAutomationPeer,
    ListViewItemAutomationPeer,
    ListViewItemDataAutomationPeer,
    LoopingSelectorAutomationPeer,
    LoopingSelectorItemAutomationPeer,
    LoopingSelectorItemDataAutomationPeer,
    MapControlAutomationPeer,
    MediaElementAutomationPeer,
    MediaPlayerElementAutomationPeer,
    MediaTransportControlsAutomationPeer,
    MenuBarAutomationPeer,
    MenuBarItemAutomationPeer,
    MenuFlyoutItemAutomationPeer,
    MenuFlyoutPresenterAutomationPeer,
    NavigationViewItemAutomationPeer,
    PasswordBoxAutomationPeer,
    PersonPictureAutomationPeer,
    PickerFlyoutPresenterAutomationPeer,
    PivotAutomationPeer,
    PivotItemAutomationPeer,
    PivotItemDataAutomationPeer,
    ProgressBarAutomationPeer,
    ProgressRingAutomationPeer,
    RadioButtonAutomationPeer,
    RangeBaseAutomationPeer,
    RatingControlAutomationPeer,
    RepeatButtonAutomationPeer,
    RichEditBoxAutomationPeer,
    RichTextBlockAutomationPeer,
    RichTextBlockOverflowAutomationPeer,
    ScrollBarAutomationPeer,
    ScrollViewerAutomationPeer,
    SearchBoxAutomationPeer,
    SelectorAutomationPeer,
    SelectorItemAutomationPeer,
    SemanticZoomAutomationPeer,
    SettingsFlyoutAutomationPeer,
    SliderAutomationPeer,
    TextBlockAutomationPeer,
    TextBoxAutomationPeer,
    ThumbAutomationPeer,
    TimePickerAutomationPeer,
    TimePickerFlyoutPresenterAutomationPeer,
    ToggleButtonAutomationPeer,
    ToggleMenuFlyoutItemAutomationPeer,
    ToggleSwitchAutomationPeer,
    TreeViewItemAutomationPeer,
    TreeViewListAutomationPeer,
)
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from winrt._winrt_windows_ui_xaml_automation_peers import (
        AppBarAutomationPeer_Static,
        AppBarButtonAutomationPeer_Static,
        AppBarToggleButtonAutomationPeer_Static,
        AutomationPeer_Static,
        ButtonAutomationPeer_Static,
        ButtonBaseAutomationPeer_Static,
        CalendarDatePickerAutomationPeer_Static,
        CaptureElementAutomationPeer_Static,
        CheckBoxAutomationPeer_Static,
        ColorPickerSliderAutomationPeer_Static,
        ColorSpectrumAutomationPeer_Static,
        ComboBoxAutomationPeer_Static,
        ComboBoxItemAutomationPeer_Static,
        ComboBoxItemDataAutomationPeer_Static,
        DatePickerAutomationPeer_Static,
        FlipViewAutomationPeer_Static,
        FlipViewItemAutomationPeer_Static,
        FlipViewItemDataAutomationPeer_Static,
        FlyoutPresenterAutomationPeer_Static,
        FrameworkElementAutomationPeer_Static,
        GridViewAutomationPeer_Static,
        GridViewHeaderItemAutomationPeer_Static,
        GridViewItemAutomationPeer_Static,
        GridViewItemDataAutomationPeer_Static,
        GroupItemAutomationPeer_Static,
        HubAutomationPeer_Static,
        HubSectionAutomationPeer_Static,
        HyperlinkButtonAutomationPeer_Static,
        ImageAutomationPeer_Static,
        ItemAutomationPeer_Static,
        ItemsControlAutomationPeer_Static,
        ListBoxAutomationPeer_Static,
        ListBoxItemAutomationPeer_Static,
        ListBoxItemDataAutomationPeer_Static,
        ListViewAutomationPeer_Static,
        ListViewBaseAutomationPeer_Static,
        ListViewBaseHeaderItemAutomationPeer_Static,
        ListViewHeaderItemAutomationPeer_Static,
        ListViewItemAutomationPeer_Static,
        ListViewItemDataAutomationPeer_Static,
        MediaElementAutomationPeer_Static,
        MediaPlayerElementAutomationPeer_Static,
        MediaTransportControlsAutomationPeer_Static,
        MenuBarAutomationPeer_Static,
        MenuBarItemAutomationPeer_Static,
        MenuFlyoutItemAutomationPeer_Static,
        MenuFlyoutPresenterAutomationPeer_Static,
        NavigationViewItemAutomationPeer_Static,
        PasswordBoxAutomationPeer_Static,
        PersonPictureAutomationPeer_Static,
        ProgressBarAutomationPeer_Static,
        ProgressRingAutomationPeer_Static,
        RadioButtonAutomationPeer_Static,
        RangeBaseAutomationPeer_Static,
        RatingControlAutomationPeer_Static,
        RepeatButtonAutomationPeer_Static,
        RichEditBoxAutomationPeer_Static,
        RichTextBlockAutomationPeer_Static,
        RichTextBlockOverflowAutomationPeer_Static,
        ScrollBarAutomationPeer_Static,
        ScrollViewerAutomationPeer_Static,
        SearchBoxAutomationPeer_Static,
        SelectorAutomationPeer_Static,
        SelectorItemAutomationPeer_Static,
        SemanticZoomAutomationPeer_Static,
        SettingsFlyoutAutomationPeer_Static,
        SliderAutomationPeer_Static,
        TextBlockAutomationPeer_Static,
        TextBoxAutomationPeer_Static,
        ThumbAutomationPeer_Static,
        TimePickerAutomationPeer_Static,
        ToggleButtonAutomationPeer_Static,
        ToggleMenuFlyoutItemAutomationPeer_Static,
        ToggleSwitchAutomationPeer_Static,
        TreeViewItemAutomationPeer_Static,
        TreeViewListAutomationPeer_Static,
    )

__all__ = [
    "AccessibilityView",
    "AutomationControlType",
    "AutomationEvents",
    "AutomationHeadingLevel",
    "AutomationLandmarkType",
    "AutomationLiveSetting",
    "AutomationNavigationDirection",
    "AutomationNotificationKind",
    "AutomationNotificationProcessing",
    "AutomationOrientation",
    "AutomationStructureChangeType",
    "PatternInterface",
    "RawElementProviderRuntimeId",
    "AppBarAutomationPeer",
    "AppBarButtonAutomationPeer",
    "AppBarToggleButtonAutomationPeer",
    "AutoSuggestBoxAutomationPeer",
    "AutomationPeer",
    "AutomationPeerAnnotation",
    "ButtonAutomationPeer",
    "ButtonBaseAutomationPeer",
    "CalendarDatePickerAutomationPeer",
    "CaptureElementAutomationPeer",
    "CheckBoxAutomationPeer",
    "ColorPickerSliderAutomationPeer",
    "ColorSpectrumAutomationPeer",
    "ComboBoxAutomationPeer",
    "ComboBoxItemAutomationPeer",
    "ComboBoxItemDataAutomationPeer",
    "DatePickerAutomationPeer",
    "DatePickerFlyoutPresenterAutomationPeer",
    "FlipViewAutomationPeer",
    "FlipViewItemAutomationPeer",
    "FlipViewItemDataAutomationPeer",
    "FlyoutPresenterAutomationPeer",
    "FrameworkElementAutomationPeer",
    "GridViewAutomationPeer",
    "GridViewHeaderItemAutomationPeer",
    "GridViewItemAutomationPeer",
    "GridViewItemDataAutomationPeer",
    "GroupItemAutomationPeer",
    "HubAutomationPeer",
    "HubSectionAutomationPeer",
    "HyperlinkButtonAutomationPeer",
    "ImageAutomationPeer",
    "InkToolbarAutomationPeer",
    "ItemAutomationPeer",
    "ItemsControlAutomationPeer",
    "ListBoxAutomationPeer",
    "ListBoxItemAutomationPeer",
    "ListBoxItemDataAutomationPeer",
    "ListPickerFlyoutPresenterAutomationPeer",
    "ListViewAutomationPeer",
    "ListViewBaseAutomationPeer",
    "ListViewBaseHeaderItemAutomationPeer",
    "ListViewHeaderItemAutomationPeer",
    "ListViewItemAutomationPeer",
    "ListViewItemDataAutomationPeer",
    "LoopingSelectorAutomationPeer",
    "LoopingSelectorItemAutomationPeer",
    "LoopingSelectorItemDataAutomationPeer",
    "MapControlAutomationPeer",
    "MediaElementAutomationPeer",
    "MediaPlayerElementAutomationPeer",
    "MediaTransportControlsAutomationPeer",
    "MenuBarAutomationPeer",
    "MenuBarItemAutomationPeer",
    "MenuFlyoutItemAutomationPeer",
    "MenuFlyoutPresenterAutomationPeer",
    "NavigationViewItemAutomationPeer",
    "PasswordBoxAutomationPeer",
    "PersonPictureAutomationPeer",
    "PickerFlyoutPresenterAutomationPeer",
    "PivotAutomationPeer",
    "PivotItemAutomationPeer",
    "PivotItemDataAutomationPeer",
    "ProgressBarAutomationPeer",
    "ProgressRingAutomationPeer",
    "RadioButtonAutomationPeer",
    "RangeBaseAutomationPeer",
    "RatingControlAutomationPeer",
    "RepeatButtonAutomationPeer",
    "RichEditBoxAutomationPeer",
    "RichTextBlockAutomationPeer",
    "RichTextBlockOverflowAutomationPeer",
    "ScrollBarAutomationPeer",
    "ScrollViewerAutomationPeer",
    "SearchBoxAutomationPeer",
    "SelectorAutomationPeer",
    "SelectorItemAutomationPeer",
    "SemanticZoomAutomationPeer",
    "SettingsFlyoutAutomationPeer",
    "SliderAutomationPeer",
    "TextBlockAutomationPeer",
    "TextBoxAutomationPeer",
    "ThumbAutomationPeer",
    "TimePickerAutomationPeer",
    "TimePickerFlyoutPresenterAutomationPeer",
    "ToggleButtonAutomationPeer",
    "ToggleMenuFlyoutItemAutomationPeer",
    "ToggleSwitchAutomationPeer",
    "TreeViewItemAutomationPeer",
    "TreeViewListAutomationPeer",
]

class AccessibilityView(enum.IntEnum):
    RAW = 0
    CONTROL = 1
    CONTENT = 2

class AutomationControlType(enum.IntEnum):
    BUTTON = 0
    CALENDAR = 1
    CHECK_BOX = 2
    COMBO_BOX = 3
    EDIT = 4
    HYPERLINK = 5
    IMAGE = 6
    LIST_ITEM = 7
    LIST = 8
    MENU = 9
    MENU_BAR = 10
    MENU_ITEM = 11
    PROGRESS_BAR = 12
    RADIO_BUTTON = 13
    SCROLL_BAR = 14
    SLIDER = 15
    SPINNER = 16
    STATUS_BAR = 17
    TAB = 18
    TAB_ITEM = 19
    TEXT = 20
    TOOL_BAR = 21
    TOOL_TIP = 22
    TREE = 23
    TREE_ITEM = 24
    CUSTOM = 25
    GROUP = 26
    THUMB = 27
    DATA_GRID = 28
    DATA_ITEM = 29
    DOCUMENT = 30
    SPLIT_BUTTON = 31
    WINDOW = 32
    PANE = 33
    HEADER = 34
    HEADER_ITEM = 35
    TABLE = 36
    TITLE_BAR = 37
    SEPARATOR = 38
    SEMANTIC_ZOOM = 39
    APP_BAR = 40

class AutomationEvents(enum.IntEnum):
    TOOL_TIP_OPENED = 0
    TOOL_TIP_CLOSED = 1
    MENU_OPENED = 2
    MENU_CLOSED = 3
    AUTOMATION_FOCUS_CHANGED = 4
    INVOKE_PATTERN_ON_INVOKED = 5
    SELECTION_ITEM_PATTERN_ON_ELEMENT_ADDED_TO_SELECTION = 6
    SELECTION_ITEM_PATTERN_ON_ELEMENT_REMOVED_FROM_SELECTION = 7
    SELECTION_ITEM_PATTERN_ON_ELEMENT_SELECTED = 8
    SELECTION_PATTERN_ON_INVALIDATED = 9
    TEXT_PATTERN_ON_TEXT_SELECTION_CHANGED = 10
    TEXT_PATTERN_ON_TEXT_CHANGED = 11
    ASYNC_CONTENT_LOADED = 12
    PROPERTY_CHANGED = 13
    STRUCTURE_CHANGED = 14
    DRAG_START = 15
    DRAG_CANCEL = 16
    DRAG_COMPLETE = 17
    DRAG_ENTER = 18
    DRAG_LEAVE = 19
    DROPPED = 20
    LIVE_REGION_CHANGED = 21
    INPUT_REACHED_TARGET = 22
    INPUT_REACHED_OTHER_ELEMENT = 23
    INPUT_DISCARDED = 24
    WINDOW_CLOSED = 25
    WINDOW_OPENED = 26
    CONVERSION_TARGET_CHANGED = 27
    TEXT_EDIT_TEXT_CHANGED = 28
    LAYOUT_INVALIDATED = 29

class AutomationHeadingLevel(enum.IntEnum):
    NONE = 0
    LEVEL1 = 1
    LEVEL2 = 2
    LEVEL3 = 3
    LEVEL4 = 4
    LEVEL5 = 5
    LEVEL6 = 6
    LEVEL7 = 7
    LEVEL8 = 8
    LEVEL9 = 9

class AutomationLandmarkType(enum.IntEnum):
    NONE = 0
    CUSTOM = 1
    FORM = 2
    MAIN = 3
    NAVIGATION = 4
    SEARCH = 5

class AutomationLiveSetting(enum.IntEnum):
    OFF = 0
    POLITE = 1
    ASSERTIVE = 2

class AutomationNavigationDirection(enum.IntEnum):
    PARENT = 0
    NEXT_SIBLING = 1
    PREVIOUS_SIBLING = 2
    FIRST_CHILD = 3
    LAST_CHILD = 4

class AutomationNotificationKind(enum.IntEnum):
    ITEM_ADDED = 0
    ITEM_REMOVED = 1
    ACTION_COMPLETED = 2
    ACTION_ABORTED = 3
    OTHER = 4

class AutomationNotificationProcessing(enum.IntEnum):
    IMPORTANT_ALL = 0
    IMPORTANT_MOST_RECENT = 1
    ALL = 2
    MOST_RECENT = 3
    CURRENT_THEN_MOST_RECENT = 4

class AutomationOrientation(enum.IntEnum):
    NONE = 0
    HORIZONTAL = 1
    VERTICAL = 2

class AutomationStructureChangeType(enum.IntEnum):
    CHILD_ADDED = 0
    CHILD_REMOVED = 1
    CHILDREN_INVALIDATED = 2
    CHILDREN_BULK_ADDED = 3
    CHILDREN_BULK_REMOVED = 4
    CHILDREN_REORDERED = 5

class PatternInterface(enum.IntEnum):
    INVOKE = 0
    SELECTION = 1
    VALUE = 2
    RANGE_VALUE = 3
    SCROLL = 4
    SCROLL_ITEM = 5
    EXPAND_COLLAPSE = 6
    GRID = 7
    GRID_ITEM = 8
    MULTIPLE_VIEW = 9
    WINDOW = 10
    SELECTION_ITEM = 11
    DOCK = 12
    TABLE = 13
    TABLE_ITEM = 14
    TOGGLE = 15
    TRANSFORM = 16
    TEXT = 17
    ITEM_CONTAINER = 18
    VIRTUALIZED_ITEM = 19
    TEXT2 = 20
    TEXT_CHILD = 21
    TEXT_RANGE = 22
    ANNOTATION = 23
    DRAG = 24
    DROP_TARGET = 25
    OBJECT_MODEL = 26
    SPREADSHEET = 27
    SPREADSHEET_ITEM = 28
    STYLES = 29
    TRANSFORM2 = 30
    SYNCHRONIZED_INPUT = 31
    TEXT_EDIT = 32
    CUSTOM_NAVIGATION = 33

